pub struct SpectatorSettings {
pub active_spectator: Option<Entity>,
pub active_window: Option<Entity>,
pub base_speed: f32,
pub alt_speed: f32,
pub sensitivity: f32,
pub orthographic: bool,
}Expand description
A Resource for controlling Spectators.
Fields
active_spectator: Option<Entity>The Entity of the active Spectator. (Default: None)
Use this to control which Spectator you are using.
If the init feature is enabled, None will update to a single, marked camera.
Setting to None will disable the spectator mode.
active_window: Option<Entity>The Entity of the active Window. (Default: None)
Use this to control which Window will grab your mouse/hide the cursor.
If None, the primary window will be used.
base_speed: f32The base speed of the active Spectator. (Default: 10.0)
Use this to control how fast the Spectator normally moves.
alt_speed: f32The alternate speed of the active Spectator. (Default: 50.0)
Use this to control how fast the Spectator moves when you hold Shift.
sensitivity: f32The camera sensitivity of the active Spectator. (Default: 0.001)
Use this to control how fast the Spectator turns when you move the mouse.
orthographic: boolUse a control scheme more fit for orthographic (2D) rendering
Disables mouse capturing and hiding, prevents moving along z-axis and uses W and S for y-axis movement